# API Reference

## Core APIs

```{eval-rst}
    .. autofunction:: spinspg.get_spin_symmetry
```

## Spin-only group

```{eval-rst}
    .. autoenum:: spinspg.spin.SpinOnlyGroupType
```

```{eval-rst}
    .. autoclass:: spinspg.spin.SpinOnlyGroup
```

## Nontrivial spin point group

```{eval-rst}
    .. autofunction:: spinspg.pointgroup.get_pointgroup_representative_from_symbol
```

```{eval-rst}
    .. autofunction:: spinspg.pointgroup.get_pointgroup_representative
```
